diff --git a/test/porousmediumflow/1p/implicit/1ptestproblem.hh b/test/porousmediumflow/1p/implicit/1ptestproblem.hh
index 18ceeeb4549f94e337d153cfb322d42c5dc99316..0c6d2e076012a70ad1cdcc17012f1d72f3412173 100644
--- a/test/porousmediumflow/1p/implicit/1ptestproblem.hh
+++ b/test/porousmediumflow/1p/implicit/1ptestproblem.hh
@@ -82,17 +82,17 @@ NEW_TYPE_TAG(OnePTestCCProblemWithAMG, INHERITS_FROM(OnePTestCCProblem));
 SET_TYPE_PROP(OnePTestBoxProblemWithAMG, LinearSolver, Dumux::AMGBackend<TypeTag> );
 SET_TYPE_PROP(OnePTestCCProblemWithAMG, LinearSolver, Dumux::AMGBackend<TypeTag> );
 
-// if AlbertaGrid is available, test for dim < dimWorld
-#if HAVE_ALBERTA
+// if FoamGrid is available, test for dim < dimWorld
+#if HAVE_DUNE_FOAMGRID
 NEW_TYPE_TAG(OnePOneDThreeDTestProblem, INHERITS_FROM(OnePTestProblem));
 NEW_TYPE_TAG(OnePOneDThreeDTestBoxProblem, INHERITS_FROM(BoxModel, OnePOneDThreeDTestProblem));
 NEW_TYPE_TAG(OnePOneDThreeDTestCCProblem, INHERITS_FROM(CCModel, OnePOneDThreeDTestProblem));
-SET_TYPE_PROP(OnePOneDThreeDTestProblem, Grid, Dune::AlbertaGrid<1, 3>);
+SET_TYPE_PROP(OnePOneDThreeDTestProblem, Grid, Dune::FoamGrid<1, 3>);
 
 NEW_TYPE_TAG(OnePTwoDThreeDTestProblem, INHERITS_FROM(OnePTestProblem));
 NEW_TYPE_TAG(OnePTwoDThreeDTestBoxProblem, INHERITS_FROM(BoxModel, OnePTwoDThreeDTestProblem));
 NEW_TYPE_TAG(OnePTwoDThreeDTestCCProblem, INHERITS_FROM(CCModel, OnePTwoDThreeDTestProblem));
-SET_TYPE_PROP(OnePTwoDThreeDTestProblem, Grid, Dune::AlbertaGrid<2, 3>);
+SET_TYPE_PROP(OnePTwoDThreeDTestProblem, Grid, Dune::FoamGrid<2, 3>);
 #endif
 
 // Enable gravity
diff --git a/test/porousmediumflow/1p/implicit/CMakeLists.txt b/test/porousmediumflow/1p/implicit/CMakeLists.txt
index 2648932a4adaf909adef5a6d191c7caa2c349642..ae6d385d03d498361d0c2c9813a02ac9b5ad6ed1 100644
--- a/test/porousmediumflow/1p/implicit/CMakeLists.txt
+++ b/test/porousmediumflow/1p/implicit/CMakeLists.txt
@@ -63,14 +63,13 @@ add_dumux_test(test_cc1pniconvection test_cc1pniconvection test_cc1pniconvection
                          ${CMAKE_CURRENT_BINARY_DIR}/cc1pniconvection-00011.vtu
                  --command "${CMAKE_CURRENT_BINARY_DIR}/test_cc1pniconvection")
 
-# dim < dimWorld tests
+# dim < dimWorld tests with foamgrid
 add_dumux_test(test_box1p1d3d test_box1p1d3d test_box1p1d3d.cc
                python ${CMAKE_SOURCE_DIR}/bin/runtest.py
                  --script fuzzy
                  --files ${CMAKE_SOURCE_DIR}/test/references/1ptestbox1d3d-reference.vtp
                          ${CMAKE_CURRENT_BINARY_DIR}/1ptestbox1d3d-00002.vtp
                  --command "${CMAKE_CURRENT_BINARY_DIR}/test_box1p1d3d")
-add_dune_alberta_flags(test_box1p1d3d GRIDDIM 1 WORLDDIM 3)
 
 add_dumux_test(test_box1p2d3d test_box1p2d3d test_box1p2d3d.cc
                python ${CMAKE_SOURCE_DIR}/bin/runtest.py
@@ -78,7 +77,6 @@ add_dumux_test(test_box1p2d3d test_box1p2d3d test_box1p2d3d.cc
                  --files ${CMAKE_SOURCE_DIR}/test/references/1ptestbox2d3d-reference.vtu
                          ${CMAKE_CURRENT_BINARY_DIR}/1ptestbox2d3d-00002.vtu
                  --command "${CMAKE_CURRENT_BINARY_DIR}/test_box1p2d3d")
-add_dune_alberta_flags(test_box1p2d3d GRIDDIM 2 WORLDDIM 3)
 
 add_dumux_test(test_cc1p1d3d test_cc1p1d3d test_cc1p1d3d.cc
                python ${CMAKE_SOURCE_DIR}/bin/runtest.py
@@ -86,7 +84,6 @@ add_dumux_test(test_cc1p1d3d test_cc1p1d3d test_cc1p1d3d.cc
                  --files ${CMAKE_SOURCE_DIR}/test/references/1ptestcc1d3d-reference.vtp
                          ${CMAKE_CURRENT_BINARY_DIR}/1ptestcc1d3d-00002.vtp
                  --command "${CMAKE_CURRENT_BINARY_DIR}/test_cc1p1d3d")
-add_dune_alberta_flags(test_cc1p1d3d GRIDDIM 1 WORLDDIM 3)
 
 add_dumux_test(test_cc1p2d3d test_cc1p2d3d test_cc1p2d3d.cc
                python ${CMAKE_SOURCE_DIR}/bin/runtest.py
@@ -94,7 +91,6 @@ add_dumux_test(test_cc1p2d3d test_cc1p2d3d test_cc1p2d3d.cc
                  --files ${CMAKE_SOURCE_DIR}/test/references/1ptestcc2d3d-reference.vtu
                          ${CMAKE_CURRENT_BINARY_DIR}/1ptestcc2d3d-00002.vtu
                  --command "${CMAKE_CURRENT_BINARY_DIR}/test_cc1p2d3d")
-add_dune_alberta_flags(test_cc1p2d3d GRIDDIM 2 WORLDDIM 3)
 
 
 #install sources
diff --git a/test/porousmediumflow/1p/implicit/test_box1p1d3d.cc b/test/porousmediumflow/1p/implicit/test_box1p1d3d.cc
index ead71ba7cf9fe4ab3e864cc2600800e03dfe7e7f..0da90bc7d5c5d097681d1c9645bf631134f676b9 100644
--- a/test/porousmediumflow/1p/implicit/test_box1p1d3d.cc
+++ b/test/porousmediumflow/1p/implicit/test_box1p1d3d.cc
@@ -59,12 +59,12 @@ void usage(const char *progName, const std::string &errorMsg)
 
 int main(int argc, char** argv)
 {
-#if HAVE_ALBERTA
+#if HAVE_DUNE_FOAMGRID
     typedef TTAG(OnePOneDThreeDTestBoxProblem) ProblemTypeTag;
     return Dumux::start<ProblemTypeTag>(argc, argv, usage);
 #else
-#warning External grid Alberta needed to run this example.
-    std::cerr << "Test skipped, it needs Alberta!" << std::endl;
+#warning External grid module dune-foamgrid needed to run this example.
+    std::cerr << "Test skipped, it needs dune-foamgrid!" << std::endl;
     return 77;
 #endif
 }
diff --git a/test/porousmediumflow/1p/implicit/test_box1p2d3d.cc b/test/porousmediumflow/1p/implicit/test_box1p2d3d.cc
index 2b3c60193a5c51d27bcc546e93f5c549169a6003..ad262e065cc2fba88d792efb8a0b669db9fd9e8d 100644
--- a/test/porousmediumflow/1p/implicit/test_box1p2d3d.cc
+++ b/test/porousmediumflow/1p/implicit/test_box1p2d3d.cc
@@ -59,12 +59,12 @@ void usage(const char *progName, const std::string &errorMsg)
 
 int main(int argc, char** argv)
 {
-#if HAVE_ALBERTA
+#if HAVE_DUNE_FOAMGRID
     typedef TTAG(OnePTwoDThreeDTestBoxProblem) ProblemTypeTag;
     return Dumux::start<ProblemTypeTag>(argc, argv, usage);
 #else
-#warning External grid Alberta needed to run this example.
-    std::cerr << "Test skipped, it needs Alberta!" << std::endl;
+#warning External grid module dune-foamgrid needed to run this example.
+    std::cerr << "Test skipped, it needs dune-foamgrid!" << std::endl;
     return 77;
 #endif
 }
diff --git a/test/porousmediumflow/1p/implicit/test_cc1p1d3d.cc b/test/porousmediumflow/1p/implicit/test_cc1p1d3d.cc
index 322d0ed5e34ff78de7aaf3f920cc7f0cd249c479..0ed1566786b42788796caa6eb71debe13dc1c0c2 100644
--- a/test/porousmediumflow/1p/implicit/test_cc1p1d3d.cc
+++ b/test/porousmediumflow/1p/implicit/test_cc1p1d3d.cc
@@ -59,12 +59,12 @@ void usage(const char *progName, const std::string &errorMsg)
 
 int main(int argc, char** argv)
 {
-#if HAVE_ALBERTA
+#if HAVE_DUNE_FOAMGRID
     typedef TTAG(OnePOneDThreeDTestCCProblem) ProblemTypeTag;
     return Dumux::start<ProblemTypeTag>(argc, argv, usage);
 #else
-#warning External grid Alberta needed to run this example.
-    std::cerr << "Test skipped, it needs Alberta!" << std::endl;
+#warning External grid module dune-foamgrid needed to run this example.
+    std::cerr << "Test skipped, it needs dune-foamgrid!" << std::endl;
     return 77;
 #endif
 }
diff --git a/test/porousmediumflow/1p/implicit/test_cc1p2d3d.cc b/test/porousmediumflow/1p/implicit/test_cc1p2d3d.cc
index a33ad5ffbea99ffdf931b08caff6ecbf40d2844f..2a7d1e6e5a021e57c3f03c0b83a5d16f7e127304 100644
--- a/test/porousmediumflow/1p/implicit/test_cc1p2d3d.cc
+++ b/test/porousmediumflow/1p/implicit/test_cc1p2d3d.cc
@@ -59,12 +59,12 @@ void usage(const char *progName, const std::string &errorMsg)
 
 int main(int argc, char** argv)
 {
-#if HAVE_ALBERTA
+#if HAVE_DUNE_FOAMGRID
     typedef TTAG(OnePTwoDThreeDTestCCProblem) ProblemTypeTag;
     return Dumux::start<ProblemTypeTag>(argc, argv, usage);
 #else
-#warning External grid Alberta needed to run this example.
-    std::cerr << "Test skipped, it needs Alberta!" << std::endl;
+#warning External grid module dune-foamgrid needed to run this example.
+    std::cerr << "Test skipped, it needs dune-foamgrid!" << std::endl;
     return 77;
 #endif
 }